<?php

namespace App\Service;

class LogTracking
{

    private $util;
    private $logTrackingFactory;

    public function __construct (\App\Util\Util $util, \App\Factory\LogTracking $logTrackingFactory)
    {

        $this->util                = $util;
        $this->logTrackingFactory  = $logTrackingFactory;
    }

    public function errorLogs($paramsLog) {

        $errorLogs = $this->logTrackingFactory->errorLogs($paramsLog);

        return $errorLogs;
    }

    public function checkOldLogs()
    {
        try {
            $this->logTrackingFactory->deleteOldLogs($this->util->getEnv("PROJECT_DELETE_LOG_MONTH"));
            $this->logTrackingFactory->updateOldLogs($this->util->getEnv("PROJECT_UPDATE_LOG_MONTH"));
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function deleteLogs($CDINTEGRACAOERR)
    {
        $this->logTrackingFactory->deleteLogs($CDINTEGRACAOERR);
    }

    public function selectTableInteg()
    {

        $selectTableInteg = $this->logTrackingFactory->selectTableInteg();

        return $selectTableInteg;
    }

    public function selectTableFilial()
    {
        $selectTableFilial = $this->logTrackingFactory->selectTableFilial();

        return $selectTableFilial;
    }

    public function getLogDetails($cdIntegracaoErr)
    {

        $getLogDetails = $this->logTrackingFactory->getLogDetails($cdIntegracaoErr);

        if ($getLogDetails) {
            $dsArqPed = $getLogDetails[0]['DSARQPED'];

            if (empty($dsArqPed)) {
                return '';
            }

            $username = $this->util->getEnv("USERNAME_LOG");
            $password = $this->util->getEnv("PASSWORD_LOG");
            $fixedPartUrl = $this->util->getEnv("FIXED_LOG_URL");

            $completeUrl = $fixedPartUrl . $dsArqPed;

            $authHeader = "Authorization: Basic " . base64_encode("$username:$password");

            $ch = curl_init($completeUrl);
            curl_setopt($ch, CURLOPT_HTTPHEADER, array($authHeader));
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            $fileContent = curl_exec($ch);

            if (curl_errno($ch)) {
                throw new \Exception("Erro na solicitação cURL: " . curl_error($ch));
            }

            curl_close($ch);

            $json_data = json_decode($fileContent);

            if ($json_data !== null) {
                return $fileContent;
            } else {
                return '';
            }
        } else {
            throw new \Exception("Nenhum registro encontrado.");
        }
    }

    public function getParamsValue($data, $indexName) {
        $values = [];

        if (isset($data[$indexName])) {
            foreach ($data[$indexName] as $item) {
                if (isset($item[$indexName])) {
                    $values[] = $item[$indexName];
                }
            }
            return implode(',', $values);
        }

        return null;
    }

    public function ensureDTInclusaoExists(&$params) {
        if (!isset($params["DTINCLUSAO"])) {
            $params["DTINCLUSAO"] = [null, null];
        }
        return $params["DTINCLUSAO"];
    }

    public function getOrder($params) {
        if (isset($params['order'])) {
			$orderByColumns = array();
			foreach ($params['order'] as $column) {
                $column = str_replace('.', ' ', $column);
                $orderByColumns[] = strtoupper($column);
			}
    		return "ORDER BY " . implode(", ", $orderByColumns);
		}
        return "ORDER BY DTINCLUSAO ASC";
    }
}
